<?php
/*
Plugin Name: BuddyPress Quickpress
Plugin URI: http://dev.benoitgreant.be/2009/11/24/buddypress-quickpress/
Description: Allows the users to write simple posts outside the dashboard (just like QuickPress from the dashboard)
Version: 0.1-alpha
Revision Date: November 11, 2009
Requires at least: WPMU 2.8.6, BuddyPress 1.2 ?
Tested up to: What WPMU 2.8.6, BuddyPress 1.2
License: (GNU General Public License 2.0 (GPL) http://www.gnu.org/licenses/gpl.html
Author: G.Breant
Author URI: http://dev.benoitgreant.be
Site Wide Only: true
*/

//REQUIRED
require_once ( WP_PLUGIN_DIR . '/bp-quickpress/bp-quickpress-templatetags.php' );
require_once ( WP_PLUGIN_DIR . '/bp-quickpress/bp-quickpress-classes.php' );

//NAV SETUP
function bp_quickpress_setup_nav() {
	global $bp;
	if (!bp_quickpress_user_can('edit_posts')) return false;
	$blogs_link = $bp->loggedin_user->domain . $bp->blogs->slug . '/';
	bp_core_new_subnav_item( array( 'name' => __( 'QuickPress' ), 'slug' => __( 'quickpress', 'bp-quickpress-slugs' ), 'parent_url' => $blogs_link, 'parent_slug' => $bp->blogs->slug, 'screen_function' => 'bp_quickpress_screen_write_a_post', 'position' => 15 ) );
	do_action( 'bp_quickpress_setup_nav' );
}
add_action( 'plugins_loaded', 'bp_quickpress_setup_nav' );


//JS
function bp_quickpress_scripts() {
	global $bp;
	if (( $bp->current_component == $bp->blogs->slug ) && ($bp->current_action==__( 'quickpress', 'bp-quickpress-slugs' )))
	wp_enqueue_script( 'bp-quickpress-expandable-tree-js', get_stylesheet_directory_uri() . '/quickpress/_inc/js/expandableTree.js',array('jquery'), '1.0' );
	
    // Build in tag auto complete script
    wp_enqueue_script( 'suggest' );

	
}
//CSS
function bp_quickpress_css() {
	global $bp;
	if (( $bp->current_component == $bp->blogs->slug ) && ($bp->current_action==__( 'quickpress', 'bp-quickpress-slugs' )))
		wp_enqueue_style( 'bp-quickpress-screen', get_stylesheet_directory_uri() . '/quickpress/style.css' );
}


//HEAD
function bp_quickpress_head() {
	?>
	<script type="text/javascript">
	//<![CDATA[
	jQuery(document).ready( function() {
		jQuery('#quickpress #categories>ul').expandableTree();
		jQuery('#quickpress #tags').suggest("<?php echo get_bloginfo('wpurl'); ?>/wp-admin/admin-ajax.php?action=ajax-tag-search&tax=post_tag", {multiple:true, multipleSep: ","});
	});

	//]]>
	</script>
	<?php
}

//INIT
function bp_quickpress_init() {
	global $bp;
	if (( $bp->current_component == $bp->blogs->slug ) && ($bp->current_action==__( 'quickpress', 'bp-quickpress-slugs' ))) {
		add_action( 'wp_head', 'bp_quickpress_head');
		add_action( 'wp_print_styles', 'bp_quickpress_css' );
		add_action( 'wp_print_scripts', 'bp_quickpress_scripts');
	}
}

add_action( 'plugins_loaded', 'bp_quickpress_init');


function bp_quickpress_capability() {
?>
	<div id="message" class="error">
		<p><?php echo apply_filters('bp_quickpress_no_capability_msg',__( 'You do not have the capability to do this', 'bp-quickpress' )); ?></p>
	</div>
<?php
}


//SCREENS

//creation
function bp_quickpress_screen_write_a_post() {
	global $bp;

	if (!(( $bp->current_component == $bp->blogs->slug ) && (!$bp->action_variables[0]))) return false;
	
	if (!bp_quickpress_user_can('edit_posts')) add_action('bp_quickpress_after_creation_form','bp_quickpress_capability');

	do_action( 'bp_quickpress_screen_write_a_post' );

	bp_core_load_template( apply_filters( 'bp_quickpress_template_write', 'quickpress/create' ) );

}

function bp_quickpress_switch_blog($newblog_id=false) {
	global $switchblog_old_id;	
	global $wpdb;
	
	//we want to change the blog id
	if ($newblog_id) {
	
		//is the newblog != current blog ?
		global $blog_id;
		if ($newblog_id!=$blog_id) {
			$switchblog_old_id=$blog_id;
			$wpdb->set_blog_id($newblog_id);
		}
	
	//we want to restore the old blog id
	}else {
		if ($switchblog_old_id) {
			$wpdb->set_blog_id($newblog_id);
			unset($GLOBALS['switchblog_old_id']);
		}
	}
}

//edition
function bp_quickpress_screen_edit_a_post() {
	global $bp;

	if (!(( $bp->current_component == $bp->blogs->slug ) && ($bp->action_variables[0]==__( 'edit', 'bp-quickpress-slugs' )))) return false;
	
	
	if ($_REQUEST['post_id'])
		query_posts('p='.$_REQUEST['post_id']);

	global $wp_query;
	global $wpdb;
	
	
	$quickpress_post=$wp_query->posts[0];

	if ($quickpress_post)
		if ($bp->loggedin_user->id==$quickpress_post->post_author) $is_author=true;

	if ((!$quickpress_post) || (($is_author) && ((!bp_quickpress_user_can('edit_posts')))) || ((!$is_author) && ((!bp_quickpress_user_can('edit_others_posts'))))) {
		$creation_url = $bp->loggedin_user->domain . $bp->blogs->slug . '/'.__( 'quickpress', 'bp-quickpress-slugs' ).'/';
		bp_core_redirect($creation_url);

	}else {	
		do_action( 'bp_quickpress_screen_edit_a_post' );
		bp_core_load_template( apply_filters( 'bp_quickpress_template_write', 'quickpress/edit' ) );
	}

}
add_action('wp','bp_quickpress_screen_edit_a_post');

//SAVE POST
//check permissions (you can add filters)
function bp_quickpress_user_can($action) {
	
	if (current_user_can($action)) {
		$can = true;
	}else {
		$can = false;
	}
	$can = apply_filters( 'bp_quickpress_user_can', $can,$action );
	
	return $can;

}

//checks if user can publish a post
function bp_quickpress_post_status_publish() {

	if (bp_quickpress_user_can('publish_posts')) {
		$status='publish';
	}else {
		$status='pending';
	}
	return apply_filters( 'bp_quickpress_post_status_complete', $status );
}

//save
function bp_quickpress_screen_save($creation_url=false,$edition_url=false,$published_url=false,$redirect=true) {
	global $bp;
	global $blog_id;
	global $wpdb;
	
	
	
	if (!(($bp->current_component == $bp->blogs->slug ) && ($bp->current_action==__( 'quickpress', 'bp-quickpress-slugs' )))) return false;
	
	if (!$creation_url)
		$creation_url = $bp->loggedin_user->domain . $bp->blogs->slug . '/'.__( 'quickpress', 'bp-quickpress-slugs' ).'/';
		
	if (($bp->action_variables[0]=='switch-blog') && ($_POST['action']=='quickpress-switch-blog')){
	
		$switchblog_url=$creation_url.'?blog_id='.$_POST['blog_id'];
	
		bp_core_redirect($switchblog_url);
	}
	
	if ($bp->action_variables[0]!=__( 'save', 'bp-quickpress-slugs' )) return false;
	

		
	if (!bp_quickpress_user_can('edit_posts')) {
		bp_core_add_message(__( 'You do not have the capability to do this', 'bp-quickpress' ));
	}
	
	if (($_POST['action']!='quickpress-new') || (!bp_quickpress_user_can('edit_posts'))) {
		bp_core_redirect($creation_url);				
	}

	if (!$edition_url) 
		$edition_url = $bp->loggedin_user->domain . $bp->blogs->slug . '/'.__( 'quickpress', 'bp-quickpress-slugs' ).'/'.__( 'edit', 'bp-quickpress-slugs' ).'/';
		
		


	check_admin_referer( 'bp-quickpress-new-post' );

	$post_content	= $_POST['posttext'];
	$tags			= $_POST['tags'];
	$post_title		= $_POST['title'];
	
	if ((!$post_content) || (!$post_title))  {
		bp_core_add_message(__( 'Please fill the required fields (title,description).', 'bp-quickpress' ));
		bp_core_redirect($creation_url);				
	}

	//CHECK DATA
	if (($_POST['action']!='quickpress-new') || (!bp_quickpress_user_can('edit_posts'))) {
		bp_core_redirect($creation_url);				
	}
	
	$post_categories	= $_POST['categories'];
	
	$post = array(
		'post_author'	=> $bp->loggedin_user->id,
		'post_title'	=> $post_title,
		'post_content'	=> $post_content,
		'tags_input'	=> $tags,
		'post_category'	=> $post_categories
	);
	
	//POST ID
	if ($_POST['post_id']) { //existing post
		$post['ID']=$_POST['post_id'];
	}
	//POST STATUS
	if ($_POST['post_id']) { //existing post
		$post['post_status']=bp_quickpress_post_status_publish();
	}else {
		$post['post_status']=apply_filters( 'bp_quickpress_post_status_creation', 'draft' );
	}
	
	$post = apply_filters('bp_quickpress_save_content',$post);
	
	bp_quickpress_switch_blog($_REQUEST['blog_id']);

	if (!$post['ID']) { //new post
		$post_id = wp_insert_post($post);
	}else {
		$post_id = wp_update_post( $post );
	}

	
	if (!$post_id) {
		bp_core_add_message( __('Sorry, there has been an error.'), 'error' );
		bp_core_redirect($creation_url);				
	}else {
		if (!$post['ID']) {
			bp_core_add_message( __( 'Post draft saved !  Please check if everything is okay then publish it !','bp-quickpress' ));

			
			$edition_url.='?post_id='.$post_id;


			if ($_REQUEST['blog_id']) {
				$edition_url.='&blog_id='.$_REQUEST['blog_id'];
			}

			bp_core_redirect($edition_url);
			
		}else { //existing post

			if ($post['post_status']!='publish') {
				bp_core_add_message( __( 'Your post has been saved, now wait for the administrator to publish it.','bp-quickpress' ));
			}else {
				bp_core_add_message( __('Post published.'));
			}
			if ($redirect) {
				if (!$published_url) {
					$post = get_post($post['ID']);
					$published_url = $post->guid;
				}
				bp_core_redirect($published_url);
			}
			
		}
	}
	bp_quickpress_switch_blog();
	
}
add_action('plugins_loaded','bp_quickpress_screen_save');

//GET BLOG ID
//to fix : any core function instead of this ?
function bp_quickpress_blog_loop_id(){
	global $blogs_template, $bp;

	$blog =& $blogs_template->blog;
	
	return $blog['id'];
	
}


?>